@@ -9,7 +9,7 @@ use JSON::XS qw//;
 use Furl;
 use URI;
 
-our $VERSION = "0.5";
+our $VERSION = "0.6";
 
 our %OPT_TABLE = ();
 
@@ -209,8 +209,9 @@ sub setreplication { (shift)->replication(@_); }
 
 # curl -i -X PUT "http://<HOST>:<PORT>/webhdfs/v1/<PATH>?op=SETTIMES
 #                           [&modificationtime=<TIME>][&accesstime=<TIME>]"
-# motidicationtime: radix-10 long integer
+# modificationtime: radix-10 long integer
 # accesstime: radix-10 long integer
+$OPT_TABLE{SETTIMES} = [ qw( modificationtime accesstime ) ];
 sub touch {
     my ($self, $path, %options) = @_;
     my $err = $self->check_options('SETTIMES', %options);
@@ -223,6 +224,12 @@ sub touch {
     my $res = $self->operate_requests('PUT', $path, 'SETTIMES', \%options);
     $res->{code} == 200;
 }
+
+sub touchz {
+    my ($self, $path) = @_;
+    return $self->create( $path, '', overwrite => 'true' );
+}
+
 sub settimes { (shift)->touch(@_); }
 
 # sub delegation_token {}
@@ -279,7 +286,8 @@ sub operate_requests {
 
     my $headers = []; # or undef ?
     if ($self->{httpfs_mode} or not $REDIRECTED_OPERATIONS{$op}) {
-        if ($self->{httpfs_mode} and defined($payload) and length($payload) > 0) {
+        # empty files are ok
+        if ($self->{httpfs_mode} and defined($payload)) {
             $headers = ['Content-Type' => 'application/octet-stream'];
         }
         return $self->request($host, $port, $method, $path, $op, $params, $payload, $headers);
@@ -512,6 +520,10 @@ Set replica number for I<$path>. Alias: B<setreplication>.
 
 Set mtime/atime of I<$path>. Alias: B<settimes>.
 
+=head3 C<< $client->touchz($path) :Bool >>
+
+Create a zero length file.
+
 =head1 AUTHOR
 
 TAGOMORI Satoshi E<lt>tagomoris {at} gmail.comE<gt>
